@@ -33,13 +33,11 @@
 
 class FilterEdit;
 class QPushButton;
-namespace KCalCore
-{
+namespace KCalCore {
 class CalFilter;
 }
 
-namespace KPIM
-{
+namespace KPIM {
 class TagSelectionDialog;
 }
 
@@ -54,7 +52,7 @@ class FilterEditDialog : public QDialog
     Q_OBJECT
 public:
     explicit FilterEditDialog(QList<KCalCore::CalFilter *> *, QWidget *parent = nullptr);
-    virtual ~FilterEditDialog();
+    ~FilterEditDialog() override;
 
 Q_SIGNALS:
     void filterChanged();
