@@ -91,8 +91,8 @@ void KODialogManager::showOptionsDialog()
 {
     if (!mOptionsDialog) {
         mOptionsDialog = new KCMultiDialog(mMainView);
-        connect(mOptionsDialog, SIGNAL(configCommitted(QByteArray)),
-                mMainView, SLOT(updateConfig(QByteArray)));
+        connect(mOptionsDialog, QOverload<const QByteArray &>::of(&KCMultiDialog::configCommitted),
+                mMainView, QOverload<const QByteArray &>::of(&CalendarView::updateConfig));
         QStringList modules;
 
         modules.append(QStringLiteral("korganizer_configmain.desktop"));
@@ -195,13 +195,13 @@ void KODialogManager::connectTypeAhead(IncidenceEditorNG::IncidenceDialog *dialo
 void KODialogManager::connectEditor(IncidenceEditorNG::IncidenceDialog *editor)
 {
     createCategoryEditor();
-    connect(editor, SIGNAL(deleteIncidenceSignal(Akonadi::Item)), mMainView,
-            SLOT(deleteIncidence(Akonadi::Item)));
+    connect(editor, SIGNAL(deleteIncidenceSignal(Akonadi::Item)),
+            mMainView, SLOT(deleteIncidence(Akonadi::Item)));
 
-    connect(editor, SIGNAL(dialogClose(Akonadi::Item)), mMainView, SLOT(dialogClosing(
-                                                                            Akonadi::Item)));
-    connect(editor, SIGNAL(deleteAttendee(Akonadi::Item)), mMainView,
-            SIGNAL(cancelAttendees(Akonadi::Item)));
+    connect(editor, SIGNAL(dialogClose(Akonadi::Item)),
+            mMainView, SLOT(dialogClosing(Akonadi::Item)));
+    connect(editor, SIGNAL(deleteAttendee(Akonadi::Item)),
+            mMainView, SIGNAL(cancelAttendees(Akonadi::Item)));
 }
 
 void KODialogManager::updateSearchDialog()
@@ -213,7 +213,7 @@ void KODialogManager::updateSearchDialog()
 
 void KODialogManager::createCategoryEditor()
 {
-    if (mCategoryEditDialog == nullptr) {
+    if (!mCategoryEditDialog) {
         mCategoryEditDialog = new Akonadi::TagManagementDialog(mMainView);
         mCategoryEditDialog->buttons()->setStandardButtons(
             QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
