@@ -31,7 +31,9 @@ Q_DECLARE_METATYPE(QModelIndex)
 /*!
     Connect to all of the models signals.  Whenever anything happens recheck everything.
 */
-ModelTest::ModelTest(QAbstractItemModel *_model, QObject *parent) : QObject(parent), model(_model), fetchingMore(false)
+ModelTest::ModelTest(QAbstractItemModel *_model, QObject *parent) : QObject(parent)
+    , model(_model)
+    , fetchingMore(false)
 {
     Q_ASSERT(model);
 
@@ -86,7 +88,6 @@ ModelTest::ModelTest(QAbstractItemModel *_model, QObject *parent) : QObject(pare
 
 void ModelTest::runAllTests()
 {
-
     qDebug() << "runAllTests";
     if (fetchingMore) {
         return;
@@ -332,7 +333,6 @@ void ModelTest::checkChildren(const QModelIndex &parent, int currentDepth)
     qDebug() << QString(indent + QLatin1String("+")).toUtf8() << model->data(parent).toString();
 
     if (rows > 0) {
-
         Q_ASSERT(parent.column() <= 0);
         Q_ASSERT(model->hasChildren(parent));
     }
@@ -403,7 +403,8 @@ void ModelTest::checkChildren(const QModelIndex &parent, int currentDepth)
                 //qDebug() << "----";
             }/* else { if (currentDepth >= 10) qDebug() << "checked 10 deep"; };*/
             else {
-                qDebug() << QString(indent + QLatin1String("    |---")).toUtf8() << model->data(index).toString();
+                qDebug() << QString(indent + QLatin1String("    |---")).toUtf8() << model->data(
+                    index).toString();
             }
 
             // make sure that after testing the children that the index doesn't change.
@@ -480,9 +481,9 @@ void ModelTest::data()
     QVariant checkStateVariant = model->data(model->index(0, 0), Qt::CheckStateRole);
     if (checkStateVariant.isValid()) {
         int state = checkStateVariant.toInt();
-        Q_ASSERT(state == Qt::Unchecked ||
-                 state == Qt::PartiallyChecked ||
-                 state == Qt::Checked);
+        Q_ASSERT(state == Qt::Unchecked
+                 || state == Qt::PartiallyChecked
+                 || state == Qt::Checked);
         Q_UNUSED(state);
     }
 }
@@ -495,7 +496,8 @@ void ModelTest::data()
 void ModelTest::rowsAboutToBeInserted(const QModelIndex &parent, int start, int end)
 {
 //     Q_UNUSED(end);
-    qDebug() << "rowsAboutToBeInserted" << "start=" << start << "end=" << end << "parent=" << model->data(parent).toString()
+    qDebug() << "rowsAboutToBeInserted" << "start=" << start << "end=" << end << "parent="
+             << model->data(parent).toString()
              << "current count of parent=" << model->rowCount(parent);    // << "display of last=" << model->data( model->index(start-1, 0, parent) );
 //     qDebug() << model->index(start-1, 0, parent) << model->data( model->index(start-1, 0, parent) );
     Changing c;
@@ -516,7 +518,8 @@ void ModelTest::rowsInserted(const QModelIndex &parent, int start, int end)
     Changing c = insert.pop();
     Q_ASSERT(c.parent == parent);
     qDebug() << "rowsInserted"  << "start=" << start << "end=" << end << "oldsize=" << c.oldSize
-             << "parent=" << model->data(parent).toString() << "current rowcount=" << model->rowCount(parent);
+             << "parent=" << model->data(parent).toString() << "current rowcount="
+             << model->rowCount(parent);
 
     for (int ii = start; ii <= end; ++ii) {
         qDebug() << "itemWasInserted:" << model->data(model->index(ii, 0, parent));
@@ -561,7 +564,8 @@ void ModelTest::layoutChanged()
     changing.clear();
 }
 
-void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int end, const QModelIndex &destParent, int destinationRow)
+void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int end,
+                                   const QModelIndex &destParent, int destinationRow)
 {
     qDebug() << "rowsAboutToBeMoved" << srcParent << start << end << destParent << destinationRow;
     Changing cs;
@@ -579,7 +583,8 @@ void ModelTest::rowsAboutToBeMoved(const QModelIndex &srcParent, int start, int
     insert.push(cd);
 }
 
-void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end, const QModelIndex &destParent, int destinationRow)
+void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end,
+                          const QModelIndex &destParent, int destinationRow)
 {
     qDebug() << "rowsMoved" << srcParent << start << end << destParent << destinationRow;
 
@@ -591,12 +596,12 @@ void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end, cons
         // TODO: Find out what I can assert here about last and next.
 //     Q_ASSERT ( cd.last == model->data ( model->index ( destinationRow - 1, 0, cd.parent ) ) );
 //     Q_ASSERT ( cd.next == model->data ( model->index ( destinationRow + (end - start + 1), 0, cd.parent ) ) );
-
     } else {
         Q_ASSERT(cd.oldSize + (end - start + 1) == model->rowCount(destParent));
 
         Q_ASSERT(cd.last == model->data(model->index(destinationRow - 1, 0, cd.parent)));
-        Q_ASSERT(cd.next == model->data(model->index(destinationRow + (end - start + 1), 0, cd.parent)));
+        Q_ASSERT(cd.next
+                 == model->data(model->index(destinationRow + (end - start + 1), 0, cd.parent)));
     }
     Changing cs = remove.pop();
 
@@ -605,13 +610,15 @@ void ModelTest::rowsMoved(const QModelIndex &srcParent, int start, int end, cons
         Q_ASSERT(cs.oldSize == model->rowCount(srcParent));
     } else {
         Q_ASSERT(cs.oldSize - (end - start + 1) == model->rowCount(srcParent));
-        qDebug() << start - 1 << model->data(model->index(start - 1, 0, srcParent)).toString() << cs.last.toString();
-        qDebug() << start << model->data(model->index(start, 0, srcParent)).toString() << cs.next.toString();
+        qDebug() << start - 1
+                 << model->data(model->index(start - 1, 0,
+                                    srcParent)).toString() << cs.last.toString();
+        qDebug() << start
+                 << model->data(model->index(start, 0, srcParent)).toString() << cs.next.toString();
         Q_ASSERT(cs.last == model->data(model->index(start - 1, 0, srcParent)));
         qDebug() << cs.next << model->data(model->index(start, 0, srcParent));
         Q_ASSERT(cs.next == model->data(model->index(start, 0, srcParent)));
     }
-
 }
 
 /*!
